package game;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

public class GameConfig {

	public static GameConfig getInstance(String filename) throws IOException {

		GameConfig config = new GameConfig();
		FileReader reader = new FileReader(filename);
		BufferedReader bufferedReader = new BufferedReader(reader);
		String line;

		while ((line = bufferedReader.readLine()) != null) {

			int pos = line.indexOf(':');
			String id = line.substring(0, pos).trim().toLowerCase();
			String value = line.substring(pos + 1).trim();

			if (id.equals("cellheight")) {
				try {
					config.cellHeight = Integer.parseInt(value);
				} catch (NumberFormatException e) {
					System.out.println(e.toString());
				}
			} else if (id.equals("cellwidth")) {
				try {
					config.cellWidth = Integer.parseInt(value);
				} catch (NumberFormatException e) {
					System.out.println(e.toString());
				}
			} else if (id.equals("windowheight")) {
				try {
					config.windowHeight = Integer.parseInt(value);
				} catch (NumberFormatException e) {
					System.out.println(e.toString());
				}
			} else if (id.equals("windowwidth")) {
				try {
					config.windowWidth = Integer.parseInt(value);
				} catch (NumberFormatException e) {
					System.out.println(e.toString());
				}
			} else if (id.equals("imagedir")) {
				config.imageDir = value;
			} else if (id.equals("mapdir")) {
				config.mapDir = value;
			} else if (id.equals("title")) {
				config.title = value;
			}
		}

		bufferedReader.close();

		return config;
	}

	protected int cellHeight;
	protected int cellWidth;
	protected int windowHeight;
	protected int windowWidth;
	protected String imageDir;
	protected String mapDir;
	protected String title;

	public GameConfig() {

		cellHeight = 20;
		cellWidth = 20;
		windowHeight = 480;
		windowWidth = 640;
		imageDir = "../res/images";
		mapDir = "../res/maps";
		title = "Game";
	}

	public int getCellHeight() {
		return cellHeight;
	}

	public int getCellWidth() {
		return cellWidth;
	}

	public String getImageDir() {
		return imageDir;
	}

	public String getMapDir() {
		return mapDir;
	}

	public String getTitle() {
		return title;
	}

	public int getWindowHeight() {
		return windowHeight;
	}

	public int getWindowWidth() {
		return windowWidth;
	}
}
