package game.control;

import game.Game;
import game.GameUpdate;
import game.objects.Creature;
import geometry.Vector2D;

public abstract class Control {

    protected MapNode targetNode;
    protected Creature controlledCreature;
    protected Game game;

    public Control(Game game, Creature controlledCreature) {
        this.game = game;
        this.controlledCreature = controlledCreature;
        this.controlledCreature.setControl(this);
    }

    public void detach() {
        targetNode.removeEntity(controlledCreature);
        controlledCreature.setControl(null);
        controlledCreature = null;
    }

    private boolean reachedTargetNode() {

        Vector2D inverseVector = controlledCreature.getPosition()
                .subtract(targetNode.getPosition()).normalized();

        if ((int) Math.round(inverseVector.getX()) == (int) Math
                .round(controlledCreature.getDirection().getX())
                && (int) Math.round(inverseVector.getY()) == (int) Math
                        .round(controlledCreature.getDirection().getY())
                || controlledCreature.getDirection().length() == 0)
            return true;

        return false;
    }

    public void setTargetNode(MapNode targetNode) {

        if (this.targetNode != null) {
            this.targetNode.removeEntity(controlledCreature);
        }

        this.targetNode = targetNode;
        this.targetNode.addEntity(controlledCreature);
    }

    protected abstract void targetNodeReached();

    public void update(GameUpdate update) {

        controlledCreature.move(update.getTimeSinceUpdate());

        if (reachedTargetNode()) {
            targetNodeReached();
        }
    }
}
