package game.objects;

import game.Game;
import game.control.Control;
import geometry.Circle;
import geometry.Point2D;
import geometry.Vector2D;

import java.awt.image.BufferedImage;

public abstract class Creature extends Entity {

    protected Control control;
    protected Vector2D direction;
    protected double speed;

    public Creature(Game game, Circle boundingCircle, BufferedImage image,
            double speed) {
        super(game, boundingCircle, image);
        this.direction = new Vector2D(0, 0);
        this.speed = speed;
    }

    @Override
    public void destroy() {
        super.destroy();
        if (control != null) {
            control.detach();
        }
    }

    public Control getControl() {
        return control;
    }

    public Vector2D getDirection() {
        return direction;
    }

    public double getSpeed() {
        return speed;
    }

    public void move(double elapsedTime) {
    	boundingCircle.setCenter(boundingCircle.getCenter().add(
                direction.multiply(speed * elapsedTime)));
    }

    public void setControl(Control control) {
        this.control = control;
    }

    public void setDirection(Vector2D direction) {
        this.direction = direction.normalized();
    }

    public void setPosition(Point2D pos) {
        boundingCircle.setCenter(pos);
    }

    public void setSpeed(double speed) {
        this.speed = speed;
    }
}
