package game.objects;

import game.Game;
import game.control.MapNode;
import geometry.Circle;
import geometry.Point2D;

import java.awt.Graphics;
import java.awt.image.BufferedImage;

public abstract class Entity {

    protected Game game;

    protected Circle boundingCircle;
    protected BufferedImage image;
    protected boolean destroyed;

    public Entity(Game game, Circle boundingCircle, BufferedImage image) {
        this.game = game;
        this.boundingCircle = boundingCircle;
        this.image = image;
    }

    public boolean collision(Entity e) {
        return this.boundingCircle.getCenter().distance(
                e.boundingCircle.getCenter()) <= this.boundingCircle
                .getRadius() + e.boundingCircle.getRadius();
    }
    
    public boolean isInside(MapNode n) {
        return this.boundingCircle.getCenter().distance(n.getPosition()) <= game.getConfig().getCellHeight()/2;
    }
    
    public void destroy() {
        destroyed = true;
    }

    public boolean isDestroyed() {
        return destroyed;
    }

    public void draw(Graphics g) {
        g.drawImage(image, (int) (boundingCircle.getCenter().getX() - game
                .getConfig().getCellWidth() / 2), (int) (boundingCircle
                .getCenter().getY() - game.getConfig().getCellHeight() / 2),
                null);
    }

    public Point2D getPosition() {
        return boundingCircle.getCenter();
    }
}
