package pacman;

import game.Game;
import game.GameUpdate;
import game.objects.ObjectManager;

import java.awt.Graphics;
import java.util.ArrayList;
import java.util.Iterator;

public class PacManObjectManager extends ObjectManager {

	protected ArrayList<PacMan> players;
	protected ArrayList<Ghost> monsters;
	protected ArrayList<Pille> pills;
	protected Game game;

	public PacManObjectManager(Game game) {
		this.game = game;

		this.players = new ArrayList<PacMan>();
		this.monsters = new ArrayList<Ghost>();
		this.pills = new ArrayList<Pille>();
	}

	public void addGhost(Ghost ghost) {
		monsters.add(ghost);
	}

	public void addPill(Pille pill) {
		pills.add(pill);
	}

	public void addPlayer(PacMan pacMan) {
		players.add(pacMan);
	}

	public boolean hasPacman() {
		if (this.players.size() > 0) {
			return true;
		}
		return false;
	}

	public PacMan getPacman() {
		return this.players.get(0);
	}

	public void draw(Graphics g) {
		for (Pille pill : pills) {
			pill.draw(g);
		}

		for (Ghost ghosts : monsters) {
			ghosts.draw(g);
		}

		for (PacMan pacMans : players) {
			pacMans.draw(g);
		}
	}

	public int getNumGhosts() {
		return monsters.size();
	}

	public int getNumPacMans() {
		return players.size();
	}

	public int getNumPills() {
		return pills.size();
	}

	protected void purge() {

		Iterator<Ghost> ghostIterator = monsters.iterator();
		Iterator<PacMan> pacmanIterator = players.iterator();
		Iterator<Pille> pillIterator = pills.iterator();

		while (ghostIterator.hasNext()) {
			if (ghostIterator.next().isDestroyed()) {
				ghostIterator.remove();
			}
		}

		while (pacmanIterator.hasNext()) {
			if (pacmanIterator.next().isDestroyed()) {
				pacmanIterator.remove();
			}
		}

		while (pillIterator.hasNext()) {
			if (pillIterator.next().isDestroyed()) {
				pillIterator.remove();
			}
		}
	}

	public void update(GameUpdate update) {

		for (PacMan pacMan : players) {
			pacMan.move(update.getTimeSinceUpdate());
			for (Pille pill : pills) {
				if (pacMan.collision(pill)) {
					pacMan.damage(pill);
				}
			}

			for (Ghost ghost : monsters) {
				if (pacMan.collision(ghost)) {
					pacMan.damage(ghost);
					ghost.damage(pacMan);
				}
			}
		}

		purge();

		for (PacMan pacMan : players) {
			if (pacMan.getControl() != null) {
				pacMan.getControl().update(update);
			}
		}

		for (Ghost ghost : monsters) {
			if (ghost.getControl() != null) {
				ghost.getControl().update(update);
			}
		}
	}
}
